package cafetrans;

%cafetrans::translation = (

"id"                       => "en",
"Action"                   => "Action",
"address"                  => "address",
"Address Group"            => "Address Group",
"Address Id"               => "Address Id",
"Address label"            => "Address label",
"addressl"                 => "Addresses Listing",
"Address Line 1"           => "Line 1",
"Address Line 2"           => "Line 2",
"Address Status"           => "Status",
"Address Type"             => "Type",
"Administrator mail"       => "Administrator mail",
"After connect SubFlow"    => "After connect",
"After prepare main query" => "After prepare",
"After read message"       => "After read message",
"After start transformation" => "After transformation",
"After the flow is finished" => "After the flow is finished",
"After the flow is started" => "After the flow is started",
"After write message"      => "After write",
"Aliphe : Data Quality Assessment Company" => "Aliphe : Data Quality Assessment Company",
"allobjects"               => "All objects",
"Alter Query"              => "Alter Query",
"Archival frequency"       => "Archival frequency",
"Archive Connector Id"     => "Archive Connector Id",
"Atome"                    => "Atome",
"Attrdef Id"               => "Attribute Id",
"Attrdef label"            => "Attribute label",
"attrdefl"                 => "Attributes",
"Attribut default"         => "Default value",
"Attribute Data Type"      => "Value datatype",
"Attribute for Objects of Type" => "Attribute for Objects of Type",
"Attribute Id"             => "Attribute Id",
"Attribute label"          => "Attribute Label",
"Attributes List"          => "Attributes List",
"Attribute Value"          => "Value",
"Back"                     => "Back to the list",
"Before connect SubFlow"   => "Before connect",
"Before prepare main query" => "Before prepare",
"Before read message"      => "Before read",
"Before start transformations" => "Before transformations",
"Before the flow is finished" => "Before the flow is finished",
"Before the flow is started" => "Before the flow is started",
"Before write message"     => "Before write",
"Blowfish Alogorithm"      => "Blowfish Alogorithm",
"Bottom"                   => "Bottom",
"Buffered?"                => "Buffered?",
"bufferedflow"             => "Buffered flow",
"Buffered sub flows"       => "Buffered sub flows",
"Cafeterra - a product from" => "Cafeterra - a product from",
"Cafeterra the FREE EAI"   => "Cafeterra the FREE EAI",
"cafusrl"                  => "Cafeterra users",
"Caller page"              => "Caller page",
"Change"                   => "Change",
"Check Files Permissions"  => "Check Files Permissions",
"Check Perl Modules"       => "Check Installed Perl Modules",
"choose2"                  => "== Choose an option ==",
"choose"                   => "====== Choose an option ======",
"choosemenu"               => "====== Choose an menu ======",
"Choose status"            => "= Select a status =",
"choosesubmenu"            => "====== Choose an sub menu ======",
"Comments"                 => "Comments",
"commitinterv"             => "Commit Interval",
"Committing condition"     => "Committing condition",
"Compression"              => "Compression ?",
"Conainer Id"              => "Conainer Id",
"config"                   => "Configuration",
"Confirm Drop"             => "Confirm drop",
"Connect"                  => "Connect",
"Connector"                => "Connector",
"Connector Id"             => "Connector Id",
"Connector Id Label"       => "Connector Id/Label",
"Connector info"           => "Connecto'sr info",
"Connector info"           => "Connector's info",
"Connector Label"          => "Connector's Label (local)",
"connectorl"               => "Connectors",
"Connector name"           => "Connector name",
"Connector object"         => "Connector object",
"Connector status"         => "Connector status",
"Container"                => "Container",
"Container Id"             => "Container Id",
"Container info"           => "Container's info",
"Container label"          => "Container's label",
"containerl"               => "Containers",
"Container name"           => "Container's name",
"Container object"         => "Container object",
"Container pattern"        => "Search container'spattern",
"Container pattern"        => "Search containe'r pattern",
"Container Remarks"        => "Container Remarks",
"Containers"               => "Containers",
"Container status"         => "Container status",
"Context Connector Id"     => "Data Base Connector",
"Context Id"               => "Context id",
"Context label"            => "Context label",
"contextl"                 => "Contexts",
"Copy"                     => "Copy",
"Create container if not exist" => "Create container if not exist",
"Create copy"              => "Create copy",
"Create"                   => "Create",
"Created by"               => "Created by",
"Created on"               => "Created on",
"Create Query"             => "Create Query",
"Crontab style"            => "Crontab style",
"Current function"         => "Current function",
"daemon"                   => "daemon",
"Dataformat"               => "Data format",
"Dataformat Id"            => "Dataformat Id",
"Datalength"               => "Data length",
"Datascale"                => "Data scale",
"Datatype"                 => "Data type",
"Datatype Id"              => "Datatype Id",
"datatypel"                => "Datatypes",
"Date"                     => "Last deployed date",
"days"                     => "days",
"Doc Day(s)"               => "Day(s)",
"DBI DSN"                  => "Data source name (DBI)",
"Deep Copy"                => "Deep Copy",
"Default"                  => "Default",
"Default (stop)"           => "Default (stop)",
"Default value"            => "Default value",
"Delete"                   => "Delete",
"Deleted status"           => "Deleted",
"Delete Query"             => "Delete Query",
"Del-Ins"                  => "Delete then Insert",
"dependant"                => "Dependant",
"Deploy"                   => "Deploy",
"Deploy selected objects"  => "Deploy selected objects",
"Deployed Objects Count"   => "Deployed Objects Count",
"DES Alogorithm"           => "DES Alogorithm",
"Error's Detail"           => "Error's Detail",
"Message's Detail"         => "Message's Detail",
"Disabled Status"          => "Disabled Status",
"Doc Attribute Id"         => "Attribute Id",
"Doc Attribute Label"      => "Attribute Label",
"Doc Attributes List"      => "Attributes List",
"Doc Attribute Value"      => "Attribute Value",
"Doc Buffered?"            => "Buffered?",
"Doc Comments"             => "Comments",
"Doc Compression"          => "Compression",
"Doc Conainer Id"          => "Conainer Id",
"Doc Connector External name" => "Connector External name",
"Doc Connector Id"         => "Connector Id",
"Doc Connector Label"      => "Connector Label",
"Doc Container Id"         => "Container Id",
"Doc Container Label"      => "Container Label",
"Doc Container Name"       => "Container Name",
"Doc Datatype"             => "Datatype",
"Doc DBI DSN"              => "Data source name (DBI)",
"Doc Default Value"        => "Default Value",
"Doc Driver Name"          => "Driver Name",
"Doc Encryption Key (Phase 1)" => "Encryption Key (Phase 1)",
"Doc Encryption Key (Phase 2)" => "Encryption Key (Phase 2)",
"Doc Encryption Method (Phase 1)" => "Encryption Method (Phase 1)",
"Doc Encryption Method (Phase 2)" => "Encryption Method (Phase 2)",
"Doc Env. Variable Name"   => "Env. Variable Name",
"Doc Env. Variables List"  => "Env. Variables List",
"Doc Env. Variable Type"   => "Env. Variable Type",
"Doc Env. Variable Value"  => "Env. Variable Value",
"Doc Event Id"             => "Event Id",
"Doc Events"               => "Events",
"Doc Expire Delay"         => "Expire Delay",
"Doc External Name"        => "External Name",
"Doc External Schema"      => "External Schema",
"Doc External Type"        => "External Type",
"Doc Field Externalname"   => "Field Externalname",
"Doc Field Label"          => "Field Label",
"Doc Flow Label"           => "Flow Label",
"Doc Flow Name"            => "Flow Name",
"Doc Flow Status"          => "Flow Status",
"Doc Flow Type"            => "Flow Type",
"Doc Formula"              => "Formula",
"Doc Gen Or Wait"          => "Event Type",
"Doc Host Address"         => "Host Address",
"Doc Host External name"   => "Host External name",
"Doc Host Label"           => "Host Label",
"Doc Host Status"          => "Host Status",
"Doc Field Id"             => "Doc Field Id",
"Doc Incom Relationship"   => "Incom Relationship",
"Doc Keep Alive"           => "Keep Alive",
"Doc Key Pos"              => "Key Pos",
"Doc Lang"                 => "Lang",
"Doc Length"               => "Length",
"Doc Mapping"              => "Mapping",
"Doc Modified By"          => "Modified By",
"Doc Modified On"          => "Modified On",
"Doc Null"                 => "Nullable",
"Doc Object ID"            => "Object ID",
"Doc Object Status"        => "Object Status",
"Doc On Error"             => "On Error",
"Doc On Success"           => "On Success",
"Doc Order"                => "Order",
"Doc Parse Status"         => "Parse Status",
"Doc Port Number"          => "Port Number",
"Doc Pos"                  => "Pos",
"Doc Preferred Flow Direction" => "Preferred Flow Direction",
"Doc Programs And Scripts" => "Programs And Scripts",
"Doc Protocol Name"        => "Protocol Name",
"Doc Proxy Id"             => "Proxy Id",
"Doc Proxy Label"          => "Proxy Label",
"Doc Proxy Status"         => "Proxy Status",
"Doc Raise Mail Alert"     => "Raise Mail Alert",
"Doc Scale 2"              => "Scale 2",
"Doc Script Id"            => "Script Id",
"Doc Script Label"         => "Script Label",
"Doc Script Language"      => "Script Language",
"Doc Script Text"          => "Script Text",
"Doc Script Type"          => "Script Type",
"Doc Server Id"            => "Server Id",
"Doc Source Field"         => "Source Field",
"Doc Status"               => "Status",
"Doc Step"                 => "Step",
"Doc Subflow Dir"          => "Subflow Dir",
"Doc Subflow Id"           => "Subflow Id",
"Doc Subflow Label"        => "Subflow Label",
"Doc Subflow Method"       => "Subflow Method",
"Doc Subflow Name"         => "Subflow Name",
"Doc Sublow Order"         => "Sublow Order",
"Doc Target Field"         => "Target Field",
"Document"                 => "Printable documentation",
"Doc Used For"             => "Used For",
"Doc Use Internal Rollback Space" => "Use Internal Rollback Space",
"Doc User Id"              => "User Id",
"Doc User Login"           => "User Login",
"Doc Users Id"             => "Users Id",
"Doc Users Password"       => "Users Password",
"Driver Error Code"        => "Driver Error Code",
"Driver Id"                => "Driver Id",
"Driver label"             => "Driver label",
"driverl"                  => "Drivers listing",
"Driver Name"              => "Driver Name",
"Driver"                   => "Driver",
"Drop"                     => "Drop",
"drop Query"               => "drop Query",
"Edit"                     => "Edit",
"Edit Vars"                => "Edit Vars",
"Email Address"            => "Email Address",
"Enabled Status"           => "Enabled Status",
"Encryption key (Phase 1)" => "Encryption key (Phase 1)",
"Encryption key (Phase 2)" => "Encryption key (Phase 2)",
"Encryption method (Phase 1)" => "Encryption method (Phase 1)",
"Encryption method (Phase 2)" => "Encryption method (Phase 2)",
"End of Attributes List"   => "End of Attributes List",
"Env. var"                 => "Env. var",
"Env. Variable Name"       => "Env. Variable Name",
"Env. Variables List"      => "Env. Variables List",
"Env. Variable Type"       => "Env. Variable Type",
"Env. Variable Value"      => "Env. Variable Value",
"Error Code"               => "Error Code",
"Error Context"            => "Error Context",
"Error Date"               => "Error Date",
"Error File"               => "Error File",
"Error Id"                 => "Error Id",
"Errors handler"           => "Errors handler",
"Errors occured during this transactoin" => "Errors occured during this transactoin",
"Error Text"               => "Error Text",
"Event Generated by"       => "Event Generated by",
"Event Id"                 => "Event Id",
"eventl"                   => "Events listing",
"Event Name"               => "Event Name",
"Events"                   => "Events",
"Event Type"               => "Event Type",
"Every 1000 messages"      => "Every 1000 messages",
"Every 100 messages"       => "Every 100 messages",
"Every 10 messages"        => "Every 10 messages",
"Every message"            => "Every message",
"Expire Delay"             => "Expire Delay",
"External name"            => "External name",
"External Schema"          => "External Schema",
"External Type"            => "External Type",
"extobj"                   => "External objects",
"Fax Number"               => "Fax Number",
"Field External Name"      => "Field External Name",
"Field extrnalname"        => "Field External Name",
"Field"                    => "Field",
"Field Id"                 => "Field Id",
"Field label"              => "Field label",
"fieldl"                   => "Fields listing",
"Field Name"               => "Field name",
"Field object"             => "Field object",
"Field order"              => "Field order",
"Field position"           => "Field position",
"Field position in key"    => "Field position in key",
"Fields contents"          => "Fields contents",
"Fields"                   => "Fields",
"Fields label"             => "Fields label",
"Field specific transformation" => "Field specific transformation",
"Field status"             => "Field status",
"Five Days"                => "Five Days",
"flowdef"                  => "Flow definition",
"Flow"                     => "Flow",
"Flow Id"                  => "Flow Id",
"Flow Label"               => "Flow label",
"flowl"                    => "Flow definition",
"Flow name"                => "Flow name",
"Flow object"              => "Flow object",
"Flow status"              => "Flow status",
"Flow Type"                => "Flow Type",
"Formula"                  => "Formula",
"Four Days"                => "Four Days",
"From Date"                => "From Date",
"FTP Connector Id"         => "FTP Connector Id",
"Full"                     => "Full",
"Generated events"         => "Generated events",
"Generate/Wait"            => "Generate/Wait",
"Global Commit"            => "Global Commit",
"Global"                   => "Global",
"group"                    => "Group of addresses",
"Group Id"                 => "Group Id",
"Group label"              => "Group label",
"gzip (require Compress::Zlib)" => "gzip (require Compress::Zlib)",
"Halte"                    => "Halt",
"Help"                     => "Help",
"home"                     => "Home",
"Host address"             => "Host address",
"Host label"               => "Host label",
"Host name"                => "Host local name",
"Hostsallow"               => "Allow from hosts",
"Hostsdeny"                => "Deny from hosts",
"Host status"              => "Host status",
"IDEA Alogorithm"          => "IDEA Alogorithm",
"Subflow Id"               => "Subflow Id",
"Script Id"                => "Script's Id",
"Container Id"             => "Container's Id",
"Connector Id"             => "Connector's Id",
"Import Containers"        => "Import Containers",
"Import"                   => "Import",
"Import In new Container"  => "Import In new Container",
"Import Selected"          => "Import Selected",
"Import Update existing Container" => "Import Update existing Container",
"incom and outgo"          => "Incoming and outgoing",
"incom"                    => "Incoming",
"Incominf flows relationship" => "Incoming flows relationship",
"Incoming and outgoing flows" => "Incoming and outgoing flows",
"Incoming flows"           => "Incoming flows",
"Incoming flows only"      => "Incoming flows only",
"Incom Message Id"         => "Incom Message Id",
"Incom Message"            => "Incom Message",
"Incomming flow"           => "Incoming flow",
"Incom relationship"       => "Incom relationship",
"incomrel"                 => "Incom relationship",
"independant"              => "independant",
"Insert"                   => "Insert",
"Insert Query"             => "Insert Query",
"install basedir"          => "Directory where Cafeterra is installed",
"install cgialias"         => "CGI Alias for this context",
"install contextdbname"    => "Database Name Or SID",
"install contextdsn"       => "Data source name (DBI)",
"install contextid"        => "Context Id",
"install contextlabel"     => "Context Label",
"install contextpwd"       => "Password",
"install contexttype"      => "Context Type",
"install contextuser"      => "Database use id",
"install createdb"         => "Create the database ?",
"install createdbuser"     => "Create the database user ?",
"install design"           => "Design context",
"install docalias"         => "DIR Alias for this context",
"install dropobjects"      => "Drop objects before create ?",
"install httpdpath"        => "path to httpd.conf file",
"install ignoredataerr"    => "Ignore sql error when inserting data ?",
"install ignoreobjerr"     => "Ignore sql error when creating objects ?",
"install printerrors"      => "Print errors ?",
"install masterdsn"        => "Data source name for Master Pg Database(DBI)",
"install masterpwd"        => "Master password",
"install masteruser"       => "Master user",
"Install"                  => "Install",
"install production"       => "Production (or test) context",
"Ins-Upd"                  => "Insert then Update",
"IP Address"               => "IP Address",
"Is a local field"         => "Is a local field ?",
"Is Master"                => "Is Master ?",
"Keep Alive?"              => "Keep Alive?",
"Keep Alive"               => "Keep Alive",
"key pos"                  => "key pos",
"Last Acces"               => "Last access",
"Last Exec Time"           => "Last Exec Time",
"Last modified"            => "Last modification Date",
"Last Query"               => "Last Query",
"Launch Monitor"           => "Launch the Monitor",
"Launch"                   => "Launch daemon",
"Launch once"              => "Execute once",
"Stop Monitor"             => "Stop the Monitor",
"length"                   => "length",
"List"                     => "L",
"Main Menu"                => "Main Menu",
"Mapping"                  => "Mapping",
"Master connector"         => "Master connector",
"Master Id"                => "Master Id",
"Member of Group Id"       => "Member of Group Id",
"Memebr Status"            => "Memebr Status",
"merrorl"                  => "Monitor Flow Errors",
"Mesage Data"              => "Mesage Data",
"Mesage Date"              => "Mesage Date",
"Message Id"               => "Message Id",
"Message Status"           => "Message Status",
"Method"                   => "Method",
"mflowl"                   => "Flow monitoring",
"Mobile Number"            => "Mobile Number",
"Modified by"              => "Modified by",
"Modified on"              => "Modified by",
"Modified on"              => "Modified on",
"Modify"                   => "Apply modifs",
"monitoring"               => "Monitoring",
"Local name"               => "Local name",
"New"                      => "New",
"Next Exec Time"           => "Next Exec Time",
"Next"                     => "Next",
"nochoice"                 => "==============================",
"No compression"           => "No compression",
"no"                       => "No",
"Normal"                   => "Normal",
"Not running status"       => "Not Running",
"null"                     => "Null",
"Number"                   => "Number",
"Object id"                => "Object id",
"Object Label"             => "Object label",
"Object Name"              => "Object name",
"Object Owner"             => "Object Owner",
"Objects Name"             => "Objects Name",
"Objects Status"           => "Objects Status",
"Object Status"            => "Object status",
"Objects Type"             => "Objects Type",
"Object Type"              => "Object type",
"Offline status"           => "Offline",
"Offline Status"           => "Offline Status",
"One Day"                  => "One Day",
"On Error"                 => "On error",
"Online status"            => "Online",
"Online Status"            => "Online Status",
"On success"               => "On success",
"Order"                    => "Order",
"Other connectors"         => "Other connectors",
"Other containers"         => "Other containers",
"Other script"             => "Other script",
"Outgoing flow"            => "Outgoing flow",
"Outgoing flows"           => "Outgoing flows",
"Outgoing flows only"      => "Outgoing flows only",
"outgo"                    => "Outgoing",
"Owner Id"                 => "Owner Id",
"Owner"                    => "Owner",
"Owner Type"               => "Owner Type",
"Parsed text"              => "Parsed text",
"Parse status"             => "Parse status",
"Paused status"            => "Paused",
"Perl"                     => "Perl",
"Perl scripts"             => "Perl scripts",
"Perl Type"                => "Perl Type",
"Perl Value"               => "Perl Value",
"POP3 Connector Id"        => "POP3 Connector Id",
"Port Number"              => "Port Number",
"pos"                      => "Position",
"Postal City"              => "City",
"Postal Code"              => "Postal Code",
"Preferred Flow Direction" => "Preferred Flow Direction",
"Previous"                 => "Previous",
"Printer Address"          => "Printer Address",
"Process Id"               => "Process Id",
"Program dir"              => "Program dir",
"Programs and scripts"     => "Programs and scripts",
"Programs"                 => "Programs",
"Protocol Id"              => "Protocol Id",
"Protocol label"           => "Protocol label",
"protocoll"                => "Protocols listing",
"Protocol Name"            => "Protocol Name",
"proxycafl"                => "Cafeterra Proxies",
"Proxy Id"                 => "Proxy Id",
"Proxy Label"              => "Proxy label",
"Proxy name"               => "Proxy name",
"Proxy Status"             => "Proxy status",
"Raised by"                => "Raised by",
"Raise mail alert"         => "Raise mail alert",
"Refresh Interval"         => "Refresh Interval",
"Remarks"                  => "Remarks",
"Reset"                    => "Reset",
"Running status"           => "Running status",
"Runtime Status"           => "Running status",
"scale 2"                  => "Scale",
"Scheduled hours"          => "Hours",
"Scheduled mdays"          => "Month days",
"Scheduled minutes"        => "Minutes",
"Scheduled months"         => "Months",
"Scheduled wdays"          => "Week days",
"Schedule Id"              => "Schedule Id",
"Schedule label"           => "Schedule label",
"schedulel"                => "Flow scheduling",
"Scheduler Id"             => "Scheduler Id",
"Scheduler label"          => "Scheduler label",
"Scheduler mode"           => "Scheduler mode",
"Scheduler status"         => "Scheduler status",
"Script Id"                => "Script Id",
"Script label"             => "Script label",
"Script language"          => "Script language",
"Script Name"              => "Script Name",
"Script"                   => "Script",
"Scripts Id"               => "Scripts Id",
"Scripts Label"            => "Scripts Label",
"scriptsl"                 => "Scripts & queries",
"Scripts Name"             => "Scripts Name",
"Scripts"                  => "Scripts",
"Scripts Status"           => "Scripts Status",
"Script Status"            => "Script Status",
"Script Text"              => "Script Text",
"Script Type"              => "Script Type",
"Search"                   => "Search",
"Select Query"             => "Select Query",
"Select"                   => "Select",
"Sent Date"                => "Sent Date",
"Server Id"                => "Server Id",
"Server Label"             => "Server Label",
"serverl"                  => "Servers",
"Server name"              => "Server name",
"Server"                   => "Server",
"Server status"            => "Server status",
"Seven Days"               => "Seven Days",
"Show Errs"                => "Show Errs",
"Show fields"              => "Show fields",
"Show Msgs"                => "Show Msgs",
"Show"                     => "Show",
"Simple"                   => "Simple",
"Six Days"                 => "Six Days",
"Skip"                     => "Skip",
"Slave connector"          => "Alias connector",
"SMTP Connector Id"        => "SMTP Connector Id",
"Source Field"             => "Source Field",
"Special"                  => "Special",
"Sql scripts"              => "Sql scripts",
"Sql"                      => "Sql",
"Stack Dump"               => "Stack Dump",
"Standard Dataformat"      => "Standard Dataformat",
"Standard Datatype"        => "Standard Datatype",
"Status Date"              => "Status Date",
"Status"                   => "Status",
"Step"                     => "Step",
"Stopped status"           => "Stopped status",
"Stop"                     => "Stop",
"String"                   => "String",
"Subflow dir"              => "Subflow dir",
"Sub flow global transformation" => "Sub flow global transformation",
"Subflow Id"               => "Sub flow Id",
"Sub Flow Id"              => "Sub flow Id",
"Sub Flow label"           => "Sub flow label",
"Subflow label"            => "Sub flow label",
"Subflow method"           => "Subflow method",
"Subflow Name"             => "Subflow Name",
"Sub Flow object"          => "Sub Flow object",
"Sub Flows"                => "Sub Flows",
"Sub Flow status"          => "Sub Flow status",
"subflow"                  => "Sub flow",
"Sub Flow"                 => "Sub Flow",
"Sublow order"             => "Order",
"Sub Menu"                 => "Sub-Menu",
"Supported flows"          => "Supported flows",
"Support tansaction"       => "Support transaction",
"Support transaction"      => "Support transaction",
"System Pid"               => "System Pid",
"Target field"             => "Target field",
"Three Days"               => "Three Days",
"To Date"                  => "To Date",
"Top"                      => "Top",
"Trace File"               => "Trace File",
"Transform Date"           => "Transform Date",
"Truncate Query"           => "Truncate Query",
"Try Later"                => "Try Later",
"Tuncate"                  => "Tuncate",
"Two Days"                 => "Two Days",
"Type"                     => "Type",
"Update Current Container" => "Update Current Container",
"Update Query"             => "Update Query",
"Update"                   => "Update",
"Upd-Ins"                  => "Update then Insert",
"Used For"                 => "Used For",
"Use internal rollback space" => "Use internal rollback space",
"User"                     => "Current user",
"User Object"              => "User",
"Cafeterra User Id"        => "User login",
"Connector User Id"        => "User Id",
"Proxy User Id"            => "User Id",
"User label"               => "User name",
"user login"               => "Login name",
"User Login"               => "User login",
"User Password"            => "User password",
"Users Id"                 => "Internal Id",
"Users Label"              => "User name",
"Users Login"              => "User login",
"usersl"                   => "Users",
"Users Name"               => "User name or login",
"Users Password"           => "User Password",
"Users Status"             => "User status",
"User status"              => "User Status",
"User var"                 => "User var",
"Variable ID"              => "Variable ID",
"Variables"                => "Variables",
"Waited events"            => "Waited events",
"Wait Last?"               => "Wait Last?",
"Wait last"                => "Wait last",
"Web Service"              => "Web service",
"Web Service Script"       => "Web Service Script",
"Web Serviec Object"       => "Web Serviec Object",
"Working dir"              => "Working dir",
"yes"                      => "Yes",
"Intro"                    => "<H1 align=center>Welcome on Cafeterra the FREE EAI !</H1>", #"Introuction",
"Intro text"               => "
<xfont size=1><UL>
   <LI>Configure Cafeterra using teh menu Configration (<U>Cafeterra Users</U>, <U>Contexts</U>)
   <LI>Create and maintain the external objects dictoinnary (<U>Users</U>, <U>Servers</U>, <U>Connectors</U>, <U>Containers</U>, <U>Fields</U>)
   <LI>Create and maintain your Flows and Scripts (<U>Flow Definition</U>)
   <LI>Deploy your flows in the contetxt of your choice
   <LI>Monitor your Flows with the menu Monitoring</UL></font>",


"_addresse"                => "Address Edition",
"_addressl"                => "Addresses Listing",
"Adress Group"             => "Adress Group",
"Adress Id"                => "Adress Id",
"Adress label"             => "Adress label",
"Adress Label"             => "Adress Label",
"_attrdefe"                => "Attributes edition",
"_attrdefl"                => "Attributes listing",
"_cafusre"                 => "Cafeterra users edition",
"_cafusrl"                 => "Cafeterra users listing",
"_connectore"              => "Connectors edition",
"_connectorl"              => "List of connectors",
"_connectpage"             => "Connect to CAFETERRA",
"_containere"              => "Containers edition",
"_containerl"              => "List of containers",
"_contexte"                => "Contexts edition",
"_contextl"                => "Contexts listing",
"_dataformate"             => "Data Formats edition",
"dataformatl"              => "Data formats",
"_dataformatl"             => "Data Formats listing",
"_datatypee"               => "Datatypes edition",
"_datatypel"               => "Datatypes listing",
"deleted"                  => "Deleted",
"Deploy "                  => "Deploy ",
"Detail"                   => "Detail",
"Doc Id"                   => "Id",
"_drivere"                 => "Drivers edition",
"_driverl"                 => "Drivers listing",
"Email Adress"             => "Email Address",
"_evente"                  => "Events edition",
"_eventl"                  => "Events list",
"externalname"             => "External name",
"Externalname"             => "External name",
"_fielde"                  => "Fields edition",
"_fieldl"                  => "List of fields",
"_menupage"                => "Main Menu",
"_merrore"                 => "Flow Errors Detail",
"_merrorl"                 => "Flow Errors Monitor",
"_mflowe"                  => "Flow errors edition",
"_mflowl"                  => "Flow monitor",
"_mflowm"                  => "Flow messages edition",
"_mflowv"                  => "Flow variables edition",
"_mmsgd"                   => "Flow Message Detail",
"_mmsgl"                   => "Flow Messages Monitor",
"mmsgl"                    => "Monitor Flow Messages",
"month_0"                  => "January",
"month_10"                 => "November",
"month_11"                 => "Decembre",
"month_1"                  => "Febrary",
"month_2"                  => "March",
"month_3"                  => "April",
"month_4"                  => "May",
"month_5"                  => "June",
"month_6"                  => "Jully",
"month_7"                  => "August",
"month_8"                  => "Sepetember",
"month_9"                  => "October",
"name"                     => "Name",
"Name"                     => "Name",
"_objectsl"                => "All objects",
"offline"                  => "Offline",
"Oline status"             => "Oline status",
"online"                   => "Online",
"plscr"                    => "Perl scripts",
"_protocole"               => "Protocols edition",
"_protocoll"               => "Protocols listing",
"_proxycafe"               => "Cafeterra Proxies edition",
"_proxycafl"               => "Cafeterra Proxies list",
"scale"                    => "Scale",
"_schedulee"               => "Scheduler planning edition",
"_schedulel"               => "Schedulre planning list",
"schedule"                 => "Scheduler",
"_scriptse"                => "Scripts & queries edition",
"_scriptsl"                => "Scripts & queries list",
"scrqry"                   => "Scripts & Queries",
"scrsched"                 => "Other schedules",
"_servere"                 => "Servers edition",
"_serverl"                 => "List of servers",
"_install"                 => "CONFIGURATION OF A CAFETERRA CONTEXTE",

"_sflowm"                  => "Subflow : Field mapping",
"_sflowe"                  => "Subflow : scripts and triggers",

"_flowl"                   => "Flow listing",
"_sflowl"                  => "Sub-flows listing",
"_flowep"                  => "Flow scripts and triggers",
"_flowe"                   => "Flow Edition",
"_flowes"                  => "Sub-Flows",
"_import"                  => "Import exported Cafeterra objects",
"_export"                  => "Export Cafeterra objects",
"_fieldt"                  => "Fields transformation",
"_lcontainer"              => "Import Containers definition",
"_lfield"                  => "Import Fields definition",

"sqlscr"                   => "SQL queries",
"User Id"                  => "User login",
"_userse"                  => "External users edition",
"_usersl"                  => "External users listing",
"weekday_0"                => "Sunday",
"weekday_1"                => "Monday",
"weekday_2"                => "Tuesday",
"weekday_3"                => "Wednesday",
"weekday_4"                => "Thirsday",
"weekday_5"                => "Friday",
"weekday_6"                => "Staurday",

"Addobjects"               => "Add lines",
"export Append ObjectId"   => "Append Object Id to Name",
"export Blind Passwords"   => "Clear passwords",
"export Blind User Login"  => "Clear usernames",
"Export Date"              => "Export Date",
"export Host Names and Addresses" => "Clear Host Addresses",
"Export"                   => "Export",
"exportobjects"            => "Exoprt Objects",
"export Partner Id"        => "Partner Id",
"export User Comment"      => "Commentaire",
"export User Comment"      => "Commentaire",
"Export Version"           => "Cafeterra version",
"flowmethod"               => "Methode de flux",
"Force Import"             => "Force Import",
"Import File Name"         => "File name",
"importobjects"            => "Import Objects",
"install"                  => "Configure Contexts",
"Last Import Date"         => "Last imported",
"patchdb"                  => "Patch database",
"Select For Export"        => "Select",
"Select For Import"        => "Select",
"tools"                    => "Tools",



"alter"                    => "Alter Query",
"create"                   => "Create Query",
"ctransform"               => "Field specific transformation",
"delete"                   => "Delete Query",
"drop"                     => "Drop Query",
"fafinish"                 => "After the flow is finished",
"fastart"                  => "After the flow is started",
"fbfinish"                 => "Before the flow is finished",
"fbstart"                  => "Before the flow is started",
"insert"                   => "Insert Query",
"onerror"                  => "Errors handler",
"saconnect"                => "After connect SubFlow",
"saopen"                   => "After prepare main query",
"saread"                   => "After read message",
"satransf"                 => "After start transformation",
"sawrite"                  => "After write message",
"sbconnect"                => "Before connect SubFlow",
"sbopen"                   => "Before prepare main query",
"sbread"                   => "Before read message",
"sbtransf"                 => "Before start transformations",
"sbwrite"                  => "Before write message",
"select"                   => "Select Query",
"stransform"               => "Sub flow global transformation",
"truncate"                 => "Truncate Query",
"update"                   => "Update Query",
"user"                     => "Other script",
"webservice"               => "Web Service Script",
"Continue"                 => "Continue",
"Error date"               => "Error Date",
"FORCE DEPLOY"             => "Force updates",
"Generate an sql CREATE"   => "Generate an sql CREATE",
"Generate an sql DELETE"   => "Generate an sql DELETE",
"Generate an sql DROP"     => "Generate an sql DROP",
"Generate an sql INSERT"   => "Generate an sql INSERT",
"Generate an sql SELECT"   => "Generate an sql SELECT",
"Generate an sql TRUNCATE" => "Generate an sql TRUNCATE",
"Generate an sql UPDATE"   => "Generate an sql UPDATE",
"Generate an sql query"    => "Generate an sql query",
"Installed contexts"       => "Installed contexts",
"Message types"            => "Message types",
"Set base directory"       => "Set base directory",

"rename"                   => "Rename Query",
"sbclose"                  => "Before finishing the query",
"saclose"                  => "After finishing the query",
"sbdiscon"                 => "Before disconnect the connector",
"sadiscon"                 => "After disconnect the connector",

);




# Object interface

sub new {
	bless {}, "cafetrans";
}

sub translate {
	$self = shift;
	$phrase = shift;

#	print "<BR>\n translate called with $phrase ";
	if ($cafetrans::translation{$phrase}) { $cafetrans::translation{$phrase}; }
	else { $phrase; }

}

sub gethash {
	bless \%cafetrans::translation, "cafetrans";
}
1;
